/**
 * Copyright (C) 2000 Frdric Laurent
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * @version 0.1, November 11 2000
 * @author <a href="mailto:flr@free.fr">Frederic Laurent</a>
 * @since JDK 1.2
 */

package FindGUI;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import org.python.util.PythonInterpreter;
import org.python.core.*;
import SwingAdapter.FindListRenderer;
import SwingAdapter.DbclickListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import java.io.IOException;
import java.io.File;
import FindData.FindDataModel;


public class FindGui extends JFrame implements ActionListener
{
	private JTextField whereText;
	private	JTextField whatText;
	private	JTextField bindingText;
	private JButton	searchButton;
	private JButton replaceButton;
	private JList foundlist;
	private PyObject findInstance;
/**
 * @supplierCardinality 0..1
 * @supplierRole foundlist 
 */
	private FindDataModel dataModel;
    /** @link dependency */

    /*#FindListRenderer lnkFindListRenderer;*/
    /** @link dependency */

    /*#DbclickListener lnkDbclickListener;*/
	
	public FindGui(String title) {
		super(title);
		dataModel = new FindDataModel();
		addWindowListener(new WindowAdapter() {
				public void windowClosing(WindowEvent e) { System.exit(0); }
			});
		initFinder();
	}

	protected void initFinder() {
		// Load the pyFind.py module                              
		PyObject findMod = imp.importName("pyFind", true); 
		// Get the "class FileFind"
		PyObject findClass = findMod.__getattr__("FileFind");
		// Create an instance
		findInstance = findClass.__call__();
	}
	
	public void buildData() {
		PyObject res;
		res = findInstance.invoke("setPath",new PyString(whereText.getText()));
		res = findInstance.invoke("setExprFile",
								  new PyString(whatText.getText()));
		res = findInstance.invoke("process");
		res = findInstance.invoke("getFoundFiles");

		PyObject item;
		dataModel.clear();
		for (int i = 0; (item = res.__finditem__(i)) != null; i++) {
			dataModel.addElement(item.toString());
		}		
		dataModel.updateData();
	}
	

	public Dimension getPreferredSize() {
		return new Dimension(400, 400);	
	}
	public void buildGUI() {
		// label
		JPanel labelPanel = new JPanel(new GridLayout(3,0));
		labelPanel.add(new JLabel("o"));
		labelPanel.add(new JLabel("quoi"));
		labelPanel.add(new JLabel("faire"));
		
		
		// textfield
		JPanel textPanel = new JPanel(new GridLayout(3,0));
		whereText = new JTextField();
		whatText = new JTextField();
		bindingText = new JTextField();
		textPanel.add(whereText);
		textPanel.add(whatText);
		textPanel.add(bindingText);
		
		// button
		JPanel fctPanel = new JPanel(new GridLayout(2,0));
		searchButton = new JButton("Recherche");
		searchButton.addActionListener(this);
		fctPanel.add(searchButton);

		JPanel topPanel = new JPanel(new BorderLayout());
		topPanel.setBackground(Color.gray);
		topPanel.add(labelPanel,BorderLayout.WEST);
		topPanel.add(textPanel,BorderLayout.CENTER);
		topPanel.add(fctPanel,BorderLayout.EAST);
		
		// list
		foundlist = new JList(dataModel);
		foundlist.setCellRenderer(new FindListRenderer());
		JScrollPane scrollp = new JScrollPane(foundlist);
		DbclickListener dbc = new DbclickListener(this);
		foundlist.addMouseListener(dbc);
		
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(topPanel, BorderLayout.NORTH);
		getContentPane().add(scrollp, BorderLayout.CENTER);
		
		pack();
		setVisible(true);
	}
	
	
	public void actionPerformed(ActionEvent ev) {
		if (ev.getSource()==searchButton){
			buildData();
		}
	}

	public void locationSelected(Point p) {
		if (bindingText.getText().length()>0) {
			int index = foundlist.locationToIndex(p);
			
			String val = whereText.getText()+File.separator+(String)dataModel.getElementAt(index);
			
			try {
				Runtime.getRuntime().exec(bindingText.getText()+" "+val);
			}
			catch (IOException ex){
				System.err.println("Erreur execution "+ex);
			}
		}
	}
	
}


